mix batamanta.clean (batamanta v1.0.0)

Copy Markdown View Source

Provides a quick way to clean the user system cache for dynamic downloads of the Erlang Runtime System (ERTS).

Summary

Functions

Entry point for the mix batamanta.clean task.

Functions

run(args)

Entry point for the mix batamanta.clean task.